(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22141,        485]
NotebookOptionsPosition[     21486,        458]
NotebookOutlinePosition[     21821,        473]
CellTagsIndexPosition[     21778,        470]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Scalar, EM and gravitational QNMs of Schwarzschild BHs in GR via \
matrix-valued continued fractions\n",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{
  3.5701092341113586`*^9, {3.570117652780466*^9, 3.5701176573116493`*^9}, {
   3.570118625235464*^9, 3.5701186769267683`*^9}, {3.570227375137948*^9, 
   3.570227401005803*^9}, {3.571072184950651*^9, 3.571072199211156*^9}, {
   3.577364871602784*^9, 3.57736489221531*^9}}],

Cell["\<\
This applies to 3-term matrix-valued continued relations:\
\>", "Text",
 CellChangeTimes->{{3.571072210714645*^9, 3.5710722235506067`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DET", "[", 
    RowBox[{"\[Omega]_", ",", "l_", ",", "NN0_"}], "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"**", "**", "**", "**", "**"}], "*", 
      RowBox[{"MATRICES", "**", "**"}], "*", 
      RowBox[{"**", "**", "**", "**"}]}], "*****)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Alpha]", "[", "n_", "]"}], ":=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], 
          ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], 
          ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], 
           " ", "\[Omega]", " ", 
           RowBox[{"Gamma", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "l"}], "]"}]}]}], "}"}]}], "}"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Beta]", "[", "n_", "]"}], ":=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"3", "-", 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}]}], "-", 
           RowBox[{"2", " ", "n", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}]}], "+", 
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "+", 
           RowBox[{"16", " ", "\[ImaginaryI]", " ", "n", " ", "\[Omega]"}], 
           "+", 
           RowBox[{"32", " ", 
            SuperscriptBox["\[Omega]", "2"]}]}], ",", "0", ",", "0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "l"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"n", "-", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "n", "-", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], 
             ")"}]}]}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"4", "  ", "\[Omega]", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l", "+", 
             SuperscriptBox["l", "2"], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["n", "2"]}], "+", 
             RowBox[{"2", " ", "n", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], 
               ")"}]}], "-", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Omega]"}], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
           RowBox[{"Gamma", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "l"}], "]"}]}]}], "}"}]}], "}"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Gamma]", "[", "n_", "]"}], ":=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], 
          ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n", "-", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], 
          ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"n", "-", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], 
            "2"], " ", "\[Omega]", " ", 
           RowBox[{"Gamma", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "l"}], "]"}]}]}], "}"}]}], "}"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
       "**"}], "*****)"}], "\[IndentingNewLine]", 
     RowBox[{"NN", "=", "NN0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Rp", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Rp", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "NN"}], ",", 
       RowBox[{"i", ">", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Rp", "=", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{"Inverse", "[", 
             RowBox[{
              RowBox[{"\[Beta]", "[", "i", "]"}], "+", 
              RowBox[{
               RowBox[{"\[Alpha]", "[", "i", "]"}], ".", "Rp"}]}], "]"}], ".", 
            RowBox[{"\[Gamma]", "[", "i", "]"}]}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"i", "--"}], ";"}], "\[IndentingNewLine]", "}"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{
       RowBox[{"\[Beta]", "[", "0", "]"}], "+", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", "0", "]"}], ".", "Rp"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Clear", "[", "q", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"detM", "=", 
      RowBox[{"Det", "[", "M", "]"}]}]}], "\[IndentingNewLine]", ")"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.542604971714909*^9, 3.542605051670396*^9}, {
   3.54260511029195*^9, 3.542605115502626*^9}, {3.542605269583228*^9, 
   3.542605276121422*^9}, {3.542605359230822*^9, 3.542605360255928*^9}, {
   3.542605481714141*^9, 3.542605484142354*^9}, {3.542605685808529*^9, 
   3.5426057127225857`*^9}, 3.5426058204429893`*^9, {3.542606646514923*^9, 
   3.5426066475295687`*^9}, {3.542606688173253*^9, 3.542606690256733*^9}, {
   3.542607483489251*^9, 3.542607491008306*^9}, {3.542608045400519*^9, 
   3.542608095617957*^9}, 3.542610980903796*^9, {3.542611062246586*^9, 
   3.54261106246845*^9}, {3.542611186081958*^9, 3.5426112076151342`*^9}, 
   3.542611314084827*^9, {3.5426113980670137`*^9, 3.542611415539603*^9}, {
   3.542611453513706*^9, 3.5426114543142023`*^9}, {3.542611566513139*^9, 
   3.542611570609168*^9}, {3.5426116991049213`*^9, 3.5426117124387913`*^9}, {
   3.5426119440054703`*^9, 3.5426120768532953`*^9}, {3.542612119193508*^9, 
   3.542612127666687*^9}, {3.54261218791544*^9, 3.542612211695869*^9}, {
   3.542612402296941*^9, 3.542612407861225*^9}, {3.542612439614278*^9, 
   3.542612442655856*^9}, {3.542612482702615*^9, 3.542612508150229*^9}, {
   3.542612665246744*^9, 3.5426127040441628`*^9}, 3.542613456292885*^9, 
   3.542613543569425*^9, 3.542613588618236*^9, 3.542613695563403*^9, 
   3.542614970637772*^9, {3.543822943500691*^9, 3.543823127026622*^9}, {
   3.543823171499062*^9, 3.5438232550655203`*^9}, {3.543841105148478*^9, 
   3.5438411193991127`*^9}, {3.543841711830944*^9, 3.543842001728716*^9}, {
   3.543842147740137*^9, 3.54384215964081*^9}, {3.543842278733472*^9, 
   3.5438422824358664`*^9}, {3.543842453379181*^9, 3.543842490737505*^9}, {
   3.543842531122877*^9, 3.543842531401092*^9}, {3.5438425690487547`*^9, 
   3.543842668223906*^9}, {3.5438427066836*^9, 3.543842710744196*^9}, {
   3.543842777383341*^9, 3.543842821375279*^9}, {3.543842858166881*^9, 
   3.543842875919601*^9}, {3.5438429072584877`*^9, 3.543842923278056*^9}, {
   3.543896546766494*^9, 3.543896605964642*^9}, {3.543896648908153*^9, 
   3.543896649327449*^9}, {3.5703973265959806`*^9, 3.570397352874192*^9}, {
   3.5703974172586527`*^9, 3.570397417400938*^9}, {3.5710722317755413`*^9, 
   3.571072233793817*^9}, {3.576853929177807*^9, 3.576853995219261*^9}, 
   3.576854091620274*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DET", "[", 
  RowBox[{
   RowBox[{"0.099", "-", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "5"}]], "I"}]}], ",", "2", ",", "200"}], "]"}]], "Input",
 CellChangeTimes->{{3.542605507555346*^9, 3.542605518512471*^9}, {
   3.5426057282632713`*^9, 3.542605732147642*^9}, {3.5426065461457863`*^9, 
   3.542606547653973*^9}, {3.542606698062253*^9, 3.542606749599202*^9}, 
   3.542606852590515*^9, {3.54260806672178*^9, 3.542608090361974*^9}, {
   3.5426082989348516`*^9, 3.5426083160362453`*^9}, {3.543842099648074*^9, 
   3.543842124041483*^9}, {3.5438422935767183`*^9, 3.543842297314939*^9}, {
   3.5438425092171593`*^9, 3.543842509327553*^9}, {3.543842849766543*^9, 
   3.54384285001448*^9}, {3.543842893647279*^9, 3.543842893726693*^9}, {
   3.543896634286368*^9, 3.543896658204012*^9}, {3.570397358098092*^9, 
   3.57039735822377*^9}}],

Cell[BoxData[
 RowBox[{"44.5997745820991`", "\[VeryThinSpace]", "-", 
  RowBox[{"21.50558075367661`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.543842884650682*^9, 3.543842894489043*^9}, 
   3.543842928593199*^9, {3.543896639355685*^9, 3.54389665876921*^9}, 
   3.570397358528923*^9, 3.5703974192240562`*^9, 3.576853010694357*^9, {
   3.576854070180458*^9, 3.576854093481468*^9}, 3.576855842180188*^9, 
   3.577364911368462*^9}]
}, Open  ]],

Cell["\<\
By changing the guess, we obtain the fundamental scalar, EM and gravitational \
QNM of a Schwarzschild BH in GR\
\>", "Text",
 CellChangeTimes->{{3.571072245486045*^9, 3.571072288061015*^9}, {
  3.577364923876562*^9, 3.577364925352303*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"0.48", "-", 
    RowBox[{"0.1", " ", "I"}]}]}], ";", 
  RowBox[{"(*", "scal", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"0.45", "-", 
    RowBox[{"0.1", " ", "I"}]}]}], ";", 
  RowBox[{"(*", "EM", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"0.3", "-", 
    RowBox[{"0.1", " ", "I"}]}]}], ";", 
  RowBox[{"(*", "grav", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "****)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"f4", "[", 
    RowBox[{"y_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{"DET", "[", 
    RowBox[{"y", ",", "2", ",", "400"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"y0n", "=", 
  RowBox[{"y", "/.", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f4", "[", "y", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "\[Omega]guess"}], "}"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "13"}], ",", 
      RowBox[{"PrecisionGoal", "\[Rule]", "13"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"f4", "[", "y0n", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5426054008231373`*^9, 3.5426055495998707`*^9}, {
   3.542605736968768*^9, 3.5426057372274027`*^9}, {3.542605878947279*^9, 
   3.542605879359064*^9}, {3.542606552058606*^9, 3.542606553730399*^9}, {
   3.542606629218096*^9, 3.542606678466744*^9}, {3.54260702382707*^9, 
   3.54260704561681*^9}, {3.542607339942431*^9, 3.5426073430284777`*^9}, {
   3.542607523569826*^9, 3.542607600067679*^9}, {3.542607652409339*^9, 
   3.54260766461895*^9}, 3.5426081160312977`*^9, {3.542608196615602*^9, 
   3.542608196785865*^9}, {3.542608267918515*^9, 3.542608276188797*^9}, {
   3.542608593198552*^9, 3.542608628572441*^9}, {3.542610989698888*^9, 
   3.542611050761544*^9}, {3.5426112183676643`*^9, 3.54261123474946*^9}, 
   3.542611326169321*^9, {3.5426114281432867`*^9, 3.542611437101903*^9}, {
   3.542611592318166*^9, 3.542611671641934*^9}, {3.542611899591189*^9, 
   3.542611935604395*^9}, {3.5426123865827637`*^9, 3.542612386997361*^9}, 
   3.54261247501408*^9, {3.542612532542109*^9, 3.542612560598588*^9}, {
   3.542613487316567*^9, 3.542613490094054*^9}, {3.542613615727014*^9, 
   3.542613621120682*^9}, {3.542613659378076*^9, 3.542613659537527*^9}, {
   3.542613715847782*^9, 3.542613736180241*^9}, {3.542625236401656*^9, 
   3.542625274128333*^9}, {3.542625478588785*^9, 3.54262548492128*^9}, 
   3.542625525850112*^9, {3.543842939687428*^9, 3.543843000610955*^9}, {
   3.543843043740896*^9, 3.543843043817039*^9}, {3.54384312011222*^9, 
   3.543843185770739*^9}, {3.543843506528859*^9, 3.543843506580295*^9}, {
   3.543843566239709*^9, 3.543843625219069*^9}, {3.543843804689555*^9, 
   3.543843805030229*^9}, {3.5438438662901993`*^9, 3.5438438665808573`*^9}, {
   3.5438444046609097`*^9, 3.5438444614825783`*^9}, {3.543844792121809*^9, 
   3.54384479472089*^9}, {3.543845753192051*^9, 3.543845782258739*^9}, {
   3.54384599472517*^9, 3.5438460190832253`*^9}, {3.543846419599863*^9, 
   3.54384641987246*^9}, 3.543846482447344*^9, {3.543847614259838*^9, 
   3.54384767335614*^9}, {3.543896898748715*^9, 3.543896916370389*^9}, {
   3.5438969553531837`*^9, 3.543896970352419*^9}, {3.5439009833031807`*^9, 
   3.54390099120935*^9}, {3.5703973612493258`*^9, 3.570397426228642*^9}, {
   3.57685301386102*^9, 3.576853014862311*^9}, {3.5768540983994513`*^9, 
   3.576854128720574*^9}, 3.576854338790164*^9, {3.576854412895932*^9, 
   3.57685441343079*^9}, {3.576855853270941*^9, 3.576855853960194*^9}, {
   3.576855898539603*^9, 3.5768559038696737`*^9}, {3.577364904316703*^9, 
   3.5773649330370893`*^9}}],

Cell[BoxData[
 RowBox[{"0.3736716844180421`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.08896231568893523`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.542605425185535*^9, 3.542605444704945*^9}, {
   3.5426054783022757`*^9, 3.5426055035225487`*^9}, {3.542605534188986*^9, 
   3.54260555207104*^9}, 3.542605744045899*^9, {3.542605860601015*^9, 
   3.542605886857851*^9}, 3.5426065839091253`*^9, {3.542606639683713*^9, 
   3.542606679654151*^9}, 3.542607051570507*^9, 3.542607349386736*^9, {
   3.542607514447456*^9, 3.542607604802218*^9}, {3.542607655378907*^9, 
   3.542607666378034*^9}, {3.542608111591641*^9, 3.5426081194795427`*^9}, 
   3.542608199362712*^9, {3.5426082700855417`*^9, 3.542608279093965*^9}, {
   3.542608597983741*^9, 3.542608630503278*^9}, {3.5426109961794853`*^9, 
   3.54261107525165*^9}, {3.5426112142893953`*^9, 3.542611236503063*^9}, {
   3.5426113201366568`*^9, 3.5426113427555437`*^9}, {3.542611428486331*^9, 
   3.5426114611818542`*^9}, {3.542611584074994*^9, 3.542611673191687*^9}, {
   3.542611707420248*^9, 3.542611721549191*^9}, {3.542611916306316*^9, 
   3.542611938728613*^9}, {3.542612008592119*^9, 3.542612041496007*^9}, 
   3.542612084398958*^9, 3.542612374640012*^9, {3.5426124081793127`*^9, 
   3.542612428896755*^9}, {3.5426124675403347`*^9, 3.54261247679704*^9}, {
   3.54261251016098*^9, 3.54261256373794*^9}, {3.5426126839472923`*^9, 
   3.542612696104909*^9}, {3.5426134754784307`*^9, 3.5426134945077353`*^9}, 
   3.542613553057979*^9, {3.542613596075349*^9, 3.5426136245858583`*^9}, 
   3.542613662143325*^9, {3.5426137118246*^9, 3.5426137396496487`*^9}, 
   3.542614978007985*^9, {3.5426252430326977`*^9, 3.542625277387217*^9}, 
   3.542625487165056*^9, 3.5426255275782137`*^9, {3.54384296941212*^9, 
   3.5438430035673943`*^9}, 3.5438430486488647`*^9, {3.543843122468717*^9, 
   3.543843146082528*^9}, {3.543843181095191*^9, 3.543843188428584*^9}, 
   3.54384350989159*^9, 3.543843577645937*^9, {3.5438436188092747`*^9, 
   3.5438436267891808`*^9}, 3.543843806910322*^9, 3.543843869346385*^9, 
   3.5438444637397213`*^9, 3.543844797980154*^9, {3.5438457549508657`*^9, 
   3.543845784152952*^9}, {3.5438460117076273`*^9, 3.543846021901154*^9}, 
   3.543846423083179*^9, 3.543846486195416*^9, {3.543847648165699*^9, 
   3.5438476769777527`*^9}, 3.5438969189938183`*^9, {3.543896967555382*^9, 
   3.543896971139606*^9}, {3.570397364027596*^9, 3.570397426833922*^9}, 
   3.576853015601015*^9, {3.5768540963916693`*^9, 3.576854129755411*^9}, 
   3.5768543408484364`*^9, 3.576855850670149*^9, 3.57685590497486*^9, {
   3.5773649129438457`*^9, 3.577364931331439*^9}}],

Cell[BoxData["9.576066040190106`*^-14"], "Output",
 CellChangeTimes->{{3.542605425185535*^9, 3.542605444704945*^9}, {
   3.5426054783022757`*^9, 3.5426055035225487`*^9}, {3.542605534188986*^9, 
   3.54260555207104*^9}, 3.542605744045899*^9, {3.542605860601015*^9, 
   3.542605886857851*^9}, 3.5426065839091253`*^9, {3.542606639683713*^9, 
   3.542606679654151*^9}, 3.542607051570507*^9, 3.542607349386736*^9, {
   3.542607514447456*^9, 3.542607604802218*^9}, {3.542607655378907*^9, 
   3.542607666378034*^9}, {3.542608111591641*^9, 3.5426081194795427`*^9}, 
   3.542608199362712*^9, {3.5426082700855417`*^9, 3.542608279093965*^9}, {
   3.542608597983741*^9, 3.542608630503278*^9}, {3.5426109961794853`*^9, 
   3.54261107525165*^9}, {3.5426112142893953`*^9, 3.542611236503063*^9}, {
   3.5426113201366568`*^9, 3.5426113427555437`*^9}, {3.542611428486331*^9, 
   3.5426114611818542`*^9}, {3.542611584074994*^9, 3.542611673191687*^9}, {
   3.542611707420248*^9, 3.542611721549191*^9}, {3.542611916306316*^9, 
   3.542611938728613*^9}, {3.542612008592119*^9, 3.542612041496007*^9}, 
   3.542612084398958*^9, 3.542612374640012*^9, {3.5426124081793127`*^9, 
   3.542612428896755*^9}, {3.5426124675403347`*^9, 3.54261247679704*^9}, {
   3.54261251016098*^9, 3.54261256373794*^9}, {3.5426126839472923`*^9, 
   3.542612696104909*^9}, {3.5426134754784307`*^9, 3.5426134945077353`*^9}, 
   3.542613553057979*^9, {3.542613596075349*^9, 3.5426136245858583`*^9}, 
   3.542613662143325*^9, {3.5426137118246*^9, 3.5426137396496487`*^9}, 
   3.542614978007985*^9, {3.5426252430326977`*^9, 3.542625277387217*^9}, 
   3.542625487165056*^9, 3.5426255275782137`*^9, {3.54384296941212*^9, 
   3.5438430035673943`*^9}, 3.5438430486488647`*^9, {3.543843122468717*^9, 
   3.543843146082528*^9}, {3.543843181095191*^9, 3.543843188428584*^9}, 
   3.54384350989159*^9, 3.543843577645937*^9, {3.5438436188092747`*^9, 
   3.5438436267891808`*^9}, 3.543843806910322*^9, 3.543843869346385*^9, 
   3.5438444637397213`*^9, 3.543844797980154*^9, {3.5438457549508657`*^9, 
   3.543845784152952*^9}, {3.5438460117076273`*^9, 3.543846021901154*^9}, 
   3.543846423083179*^9, 3.543846486195416*^9, {3.543847648165699*^9, 
   3.5438476769777527`*^9}, 3.5438969189938183`*^9, {3.543896967555382*^9, 
   3.543896971139606*^9}, {3.570397364027596*^9, 3.570397426833922*^9}, 
   3.576853015601015*^9, {3.5768540963916693`*^9, 3.576854129755411*^9}, 
   3.5768543408484364`*^9, 3.576855850670149*^9, 3.57685590497486*^9, {
   3.5773649129438457`*^9, 3.5773649313610973`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 589, 11, 66, "Subtitle"],
Cell[1171, 35, 149, 3, 28, "Text"],
Cell[1323, 40, 9529, 229, 390, "Input"],
Cell[CellGroupData[{
Cell[10877, 273, 874, 16, 35, "Input"],
Cell[11754, 291, 445, 7, 29, "Output"]
}, Open  ]],
Cell[12214, 301, 250, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[12489, 310, 3813, 70, 174, "Input"],
Cell[16305, 382, 2620, 36, 29, "Output"],
Cell[18928, 420, 2530, 34, 32, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
