(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    122229,       3287]
NotebookOptionsPosition[    118141,       3150]
NotebookOutlinePosition[    118476,       3165]
CellTagsIndexPosition[    118433,       3162]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Perturbation equations of a Schwarschild-(A)dS BH in Dynamical Chern-Simons \
gravity\n",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{
  3.5701092341113586`*^9, {3.570117652780466*^9, 3.5701176573116493`*^9}, {
   3.570118625235464*^9, 3.5701186769267683`*^9}, {3.570227375137948*^9, 
   3.570227401005803*^9}, {3.571072184950651*^9, 3.571072199211156*^9}, {
   3.571072309951724*^9, 3.571072360711537*^9}, {3.571072413572901*^9, 
   3.571072434365057*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "GM0", ",", "x", ",", "g", ",", "\[Phi]", ",", "\[Phi]0", ",", 
   "\[CapitalLambda]", ",", "\[CapitalPsi]", ",", "\[Alpha]", ",", "\[Gamma]",
    ",", "Y", ",", "\[CapitalSigma]", ",", "\[CapitalDelta]", ",", "NN", ",", 
   "\[Omega]", ",", "\[CapitalDelta]", ",", "\[CapitalSigma]", ",", "gff", 
   ",", "gtt", ",", "\[Phi]", ",", "M", ",", "F", ",", "V", ",", "f0", ",", 
   "f1", ",", "f2", ",", "f3", ",", "f4", ",", "\[CapitalOmega]", ",", "A", 
   ",", "\[Phi]", ",", "B", ",", "\[Zeta]", ",", "\[Phi]", ",", 
   "\[CapitalPhi]1", ",", "\[CapitalPhi]0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}], ",", 
     RowBox[{"J", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"NN", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"rh", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"X", "\[GreaterEqual]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"{", 
     RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gdd0", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"F", "[", "r", "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"X", "[", "\[Theta]", "]"}]}], "\[Epsilon]a", "*", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], 
         RowBox[{"-", "1"}]], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        SuperscriptBox["r", "2"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"X", "[", "\[Theta]", "]"}]}], "\[Epsilon]a", "*", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gddPOLAR", "=", 
   RowBox[{"0", "\[Epsilon]p", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H0", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"H2", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"KK", "[", 
          RowBox[{"r", ",", "t"}], "]"}], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"KK", "[", 
          RowBox[{"r", ",", "t"}], "]"}], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gddAXIAL", "=", 
    RowBox[{"\[Epsilon]p", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
         "0"}], "}"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ORDERa", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ORDERp", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MatrixForm", "[", "gddAXIAL", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"$HistoryLength", "=", "0"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.496820244298901*^9, {3.4968203558284407`*^9, 3.4968203581404247`*^9}, {
   3.49682248740961*^9, 3.496822507434391*^9}, {3.496822916648978*^9, 
   3.496822924245894*^9}, {3.4968253627796383`*^9, 3.496825365436624*^9}, 
   3.504365165228209*^9, 3.5043809459936323`*^9, {3.504438008491736*^9, 
   3.5044380168067007`*^9}, {3.504495748442292*^9, 3.5044957514036427`*^9}, {
   3.504496120769294*^9, 3.5044961214237957`*^9}, {3.5045400430935097`*^9, 
   3.504540043486771*^9}, 3.504540099117354*^9, {3.504855376546852*^9, 
   3.504855377019938*^9}, {3.5070126406487007`*^9, 3.5070126683387003`*^9}, {
   3.5070165389565005`*^9, 3.507016542543501*^9}, {3.5070192092245007`*^9, 
   3.5070192094035006`*^9}, {3.5070197713987007`*^9, 3.5070197715859003`*^9}, 
   3.5072287166493998`*^9, {3.5370790428078938`*^9, 3.537079043326592*^9}, {
   3.537082332873783*^9, 3.537082336116788*^9}, {3.537082380862068*^9, 
   3.537082398365637*^9}, {3.537083684886382*^9, 3.537083686680084*^9}, {
   3.537083807108232*^9, 3.537083809984517*^9}, {3.537084029485549*^9, 
   3.537084029592424*^9}, {3.537084228699411*^9, 3.537084229009631*^9}, {
   3.537093739462956*^9, 3.537093837223934*^9}, {3.537094060161274*^9, 
   3.537094250708188*^9}, {3.537094294240178*^9, 3.537094391948748*^9}, {
   3.537098735560296*^9, 3.537098742730391*^9}, 3.537098777194285*^9, 
   3.5370992500223923`*^9, {3.537100125866765*^9, 3.5371001690948153`*^9}, {
   3.537100225767215*^9, 3.537100259114603*^9}, {3.537100305753476*^9, 
   3.5371003081749353`*^9}, {3.537100491593274*^9, 3.5371004924902477`*^9}, {
   3.537158374354004*^9, 3.537158410503768*^9}, 3.537158797548081*^9, {
   3.537158899745922*^9, 3.537158932610425*^9}, {3.537159695644637*^9, 
   3.537159703152467*^9}, {3.537159958755862*^9, 3.5371599659978447`*^9}, {
   3.537160571391717*^9, 3.53716061470122*^9}, {3.5371607191431713`*^9, 
   3.537160723528596*^9}, {3.537160855851684*^9, 3.537160857974311*^9}, 
   3.5371608929671307`*^9, {3.537160936616355*^9, 3.537160951620933*^9}, {
   3.5371611515848303`*^9, 3.537161190246645*^9}, {3.537161265251857*^9, 
   3.537161266644121*^9}, {3.5371623243443117`*^9, 3.5371623330720263`*^9}, {
   3.53716364472329*^9, 3.537163666152609*^9}, 3.537165626663948*^9, 
   3.5371667811150513`*^9, 3.53716685907119*^9, {3.5371675934571466`*^9, 
   3.537167596308173*^9}, 3.5371676307084017`*^9, {3.539773125015121*^9, 
   3.539773132013299*^9}, 3.539871507573654*^9, {3.539871912636531*^9, 
   3.539871922148884*^9}, {3.53987386773501*^9, 3.539873875542519*^9}, 
   3.570189676967231*^9, {3.570201811008587*^9, 3.570201813462865*^9}, {
   3.570287856805233*^9, 3.570287860898278*^9}, 3.5702892852644567`*^9, {
   3.570289575085664*^9, 3.570289575830328*^9}, {3.5715201010026283`*^9, 
   3.5715201096742983`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {"0", "0", 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.537167594136692*^9, 3.53716759715031*^9}, 
   3.5371676311333523`*^9, 3.537168501698287*^9, 3.53716997445231*^9, 
   3.53951305725968*^9, 3.539516641898293*^9, 3.539680595924221*^9, {
   3.539773112072062*^9, 3.539773132371538*^9}, 3.53987017669186*^9, 
   3.539871510468165*^9, 3.5398719356491537`*^9, {3.539873870445753*^9, 
   3.539873876351313*^9}, 3.570189613411275*^9, 3.5701896774404078`*^9, 
   3.570201814263814*^9, 3.570203872452182*^9, 3.5702876605334053`*^9, 
   3.570287865084695*^9, 3.570288511410693*^9, 3.570289286195292*^9, 
   3.5702895766715384`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metric and co.", "Subsubsection",
 CellChangeTimes->{{3.537167687923791*^9, 3.537167693757834*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BISERIES", "[", "Z_", "]"}], ":=", 
   RowBox[{"Z", "/.", 
    RowBox[{"Union", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"X", "'"}], "[", "\[Theta]", "]"}], "2"], "\[Rule]", 
        RowBox[{"4", " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"X", "[", "\[Theta]", "]"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "''"}], "[", "\[Theta]", "]"}], "\[Rule]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", 
            RowBox[{"X", "[", "\[Theta]", "]"}]}]}], ")"}]}]}]}], "}"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gdd", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"gdd0", "+", "gddPOLAR", "+", "gddAXIAL"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"guu", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Inverse", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DET", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Det", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", 
   RowBox[{"Length", "[", "gdd", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"gdd", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "j", "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "gdd", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "guu", "]"}]}], "Input",
 CellChangeTimes->{{3.496822745111134*^9, 3.4968227573539257`*^9}, {
   3.5070135576051006`*^9, 3.5070135731427007`*^9}, 3.5370938075446243`*^9, 
   3.537095344094717*^9, {3.537098138756166*^9, 3.537098146563369*^9}, {
   3.537098271648501*^9, 3.5370982751763487`*^9}, {3.537098684015606*^9, 
   3.537098700926721*^9}, {3.537098757113214*^9, 3.537098786418333*^9}, {
   3.537159707508955*^9, 3.5371597153437366`*^9}, {3.5371599807500267`*^9, 
   3.5371599814632893`*^9}, {3.5371668606922827`*^9, 3.537166870885435*^9}, {
   3.539773144374949*^9, 3.539773144803249*^9}, {3.5702038872100897`*^9, 
   3.570203894447616*^9}, {3.570287673377071*^9, 3.570287673544053*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       RowBox[{"F", "[", "r", "]"}]}], "0", 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {"0", 
      FractionBox["1", 
       RowBox[{"F", "[", "r", "]"}]], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      SuperscriptBox["r", "2"], "0"},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"X", "[", "\[Theta]", "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.537160204249015*^9, 3.537160628530621*^9, 3.537160735436764*^9, 
   3.537160915769443*^9, 3.537160958041258*^9, 3.537161297346287*^9, 
   3.5371623375111437`*^9, 3.53716563679412*^9, 3.537166831423455*^9, 
   3.537166872153428*^9, 3.537167636419076*^9, 3.5371685193712606`*^9, 
   3.537168655407276*^9, 3.537168805822556*^9, 3.5371699901482773`*^9, 
   3.539513063027671*^9, 3.539516647286009*^9, 3.53968060184776*^9, {
   3.539773129339847*^9, 3.539773145166123*^9}, 3.539870227023986*^9, 
   3.539871514901949*^9, 3.5398719465749693`*^9, 3.53987387917838*^9, 
   3.57018963733575*^9, 3.570189683506465*^9, 3.5702018352553988`*^9, {
   3.5702038893461533`*^9, 3.570203895140481*^9}, 3.570287684863449*^9, 
   3.570287873158798*^9, 3.570288513970993*^9, 3.5702892883327913`*^9, 
   3.570289579627817*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"F", "[", "r", "]"}]]}], "0", 
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[CurlyPhi]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]]},
     {"0", 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[Theta]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[CurlyPhi]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]]}]},
     {
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[Theta]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      FractionBox["1", 
       SuperscriptBox["r", "2"]], "0"},
     {
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[CurlyPhi]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[CurlyPhi]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]]}], "0", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.537160204249015*^9, 3.537160628530621*^9, 3.537160735436764*^9, 
   3.537160915769443*^9, 3.537160958041258*^9, 3.537161297346287*^9, 
   3.5371623375111437`*^9, 3.53716563679412*^9, 3.537166831423455*^9, 
   3.537166872153428*^9, 3.537167636419076*^9, 3.5371685193712606`*^9, 
   3.537168655407276*^9, 3.537168805822556*^9, 3.5371699901482773`*^9, 
   3.539513063027671*^9, 3.539516647286009*^9, 3.53968060184776*^9, {
   3.539773129339847*^9, 3.539773145166123*^9}, 3.539870227023986*^9, 
   3.539871514901949*^9, 3.5398719465749693`*^9, 3.53987387917838*^9, 
   3.57018963733575*^9, 3.570189683506465*^9, 3.5702018352553988`*^9, {
   3.5702038893461533`*^9, 3.570203895140481*^9}, 3.570287684863449*^9, 
   3.570287873158798*^9, 3.570288513970993*^9, 3.5702892883327913`*^9, 
   3.570289579630046*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Basic definitions of the geometry (it can take some time)\
\>", "Subsubsection",
 CellChangeTimes->{{3.537161564095697*^9, 3.537161574439938*^9}, {
  3.5715199267310038`*^9, 3.571519930747239*^9}, {3.5715201291552057`*^9, 
  3.571520132080299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Christ", "[", 
       RowBox[{"i", ",", "j", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "[", 
               RowBox[{"[", "l", "]"}], "]"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"gdd", "[", 
                    RowBox[{"[", "l", "]"}], "]"}], "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"l", ",", "j"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "-", 
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"j", ",", "i"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5370982945120773`*^9, 3.537098338999887*^9}, 
   3.5370987011902533`*^9, {3.537159292461233*^9, 3.537159293431672*^9}, {
   3.537159569384078*^9, 3.537159571377721*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ruddd", "[", 
       RowBox[{"a", ",", "i", ",", "j", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"i", ",", "k", ",", "a"}], "]"}], ",", 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "-", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"i", ",", "j", ",", "a"}], "]"}], ",", 
              RowBox[{"x", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Christ", "[", 
                 RowBox[{"i", ",", "k", ",", "\[Beta]"}], "]"}], 
                RowBox[{"Christ", "[", 
                 RowBox[{"\[Beta]", ",", "j", ",", "a"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"Christ", "[", 
                 RowBox[{"i", ",", "j", ",", "\[Beta]"}], "]"}], 
                RowBox[{"Christ", "[", 
                 RowBox[{"\[Beta]", ",", "k", ",", "a"}], "]"}]}]}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Beta]", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.537098105815898*^9, 3.537098344503994*^9, {3.537098643614915*^9, 
   3.537098644536149*^9}, {3.537098809670596*^9, 3.5370988163403387`*^9}, {
   3.5371016497858553`*^9, 3.53710165396139*^9}, {3.53715845179491*^9, 
   3.5371584631917877`*^9}, {3.537159580527854*^9, 3.537159583690487*^9}, {
   3.53716004279412*^9, 3.5371600485159893`*^9}, {3.537161317859391*^9, 
   3.537161320648589*^9}, {3.537168525340242*^9, 3.53716853028098*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.1199999999999761`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.537168640871715*^9, 3.537168775696789*^9, 
  3.537168843307889*^9, 3.537170101679109*^9, 3.5395131708406897`*^9, 
  3.539516744847911*^9, 3.539680705517598*^9, 3.539870230947733*^9, 
  3.539871519473386*^9, 3.539871950917715*^9, 3.5398738817135344`*^9, 
  3.570189640647387*^9, 3.570189706120372*^9, 3.57020183947264*^9, 
  3.57020390072427*^9, 3.570287690452835*^9, 3.570287876950272*^9, 
  3.57028851814988*^9, 3.570289293287736*^9, 3.5702895856823473`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ricci", "[", 
       RowBox[{"i", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"Ruddd", "[", 
              RowBox[{"l", ",", "i", ",", "l", ",", "k"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537162534655031*^9, 3.5371625374284153`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ruu", "[", 
       RowBox[{"i", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Ricci", "[", 
               RowBox[{"l", ",", "m"}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "l", "]"}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "[", 
               RowBox[{"[", "m", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.5371008115867167`*^9, {3.537162539777337*^9, 3.5371625431261683`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SCAL", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], 
           RowBox[{"Ricci", "[", 
            RowBox[{"i", ",", "j"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.537162548098844*^9, 3.5371625504566917`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Eins", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Ricci", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "-", 
            RowBox[{
             FractionBox["1", "2"], "SCAL", " ", 
             RowBox[{"g", "[", 
              RowBox[{"i", ",", "j"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537162561041321*^9, 3.537162563183304*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Rdddd", "[", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"i", ",", "a"}], "]"}], 
              RowBox[{"Ruddd", "[", 
               RowBox[{"a", ",", "j", ",", "k", ",", "l"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"a", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5371625667042637`*^9, 3.537162572556037*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ETA", "[", 
        RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "]"}], "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"BISERIES", "[", 
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox[
               RowBox[{"-", "DET"}]]], 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"LeviCivitaTensor", "[", "dim", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}], "[", 
              RowBox[{"[", "l", "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}],
           "]"}], "]"}], "]"}]}], ";"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "dim"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.537162576627923*^9, 3.537162578978847*^9}, 
   3.5398738859530993`*^9, 3.570291015836627*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of the Pontryagin (this takes longer)\
\>", "Subsubsection",
 CellChangeTimes->{{3.537162040610279*^9, 3.537162047101716*^9}, {
   3.53716665752461*^9, 3.53716666084144*^9}, 3.570289595398344*^9, {
   3.571519940635498*^9, 3.5715199536079197`*^9}, {3.571520145149702*^9, 
   3.571520148667592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"starRdddd", "[", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"l", ",", "c"}], "]"}], 
              RowBox[{"g", "[", 
               RowBox[{"m", ",", "d"}], "]"}], 
              FractionBox["1", "2"], 
              RowBox[{"ETA", "[", 
               RowBox[{"l", ",", "m", ",", "e", ",", "f"}], "]"}], 
              RowBox[{"Rdddd", "[", 
               RowBox[{"a", ",", "b", ",", "e", ",", "f"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", "1", ",", "dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"e", ",", "1", ",", "dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"f", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"d", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.537162772084981*^9, 3.537162774648972*^9}, {
   3.537165656145398*^9, 3.537165660999501*^9}, 3.5371668974883127`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.2166660000000036`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.5371668987636013`*^9, 3.537171348574185*^9, 
  3.539870240817244*^9, 3.539871525083254*^9, 3.5398719557749767`*^9, 
  3.5398738913614807`*^9, 3.5701896531032476`*^9, 3.570189719149482*^9, 
  3.570201846563847*^9, 3.5702039084151506`*^9, 3.570287700451845*^9, 
  3.570287884598158*^9, 3.570288527666486*^9, 3.570289300834594*^9, 
  3.5702895989157047`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"NABLAR", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"BISERIES", "[", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"Ricci", "[", 
              RowBox[{"b", ",", "c"}], "]"}], ",", 
             RowBox[{"x", "[", 
              RowBox[{"[", "a", "]"}], "]"}]}], "]"}], "-", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"a", ",", "b", ",", "l"}], "]"}], 
              RowBox[{"Ricci", "[", 
               RowBox[{"l", ",", "c"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], "-", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"a", ",", "c", ",", "l"}], "]"}], 
              RowBox[{"Ricci", "[", 
               RowBox[{"b", ",", "l"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
        "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.537168827728154*^9, 3.537168830585561*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.3499999999999943`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.537171710622162*^9, 3.539870256886958*^9, 
  3.539871526918912*^9, 3.539871957166131*^9, 3.539873893484314*^9, 
  3.5701897443776817`*^9, 3.5702018521175003`*^9, 3.5702039202339783`*^9, 
  3.570287893531671*^9, 3.5702885315099907`*^9, 3.570289302924795*^9, 
  3.570289605134272*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"starRR", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "a", "]"}], "]"}], "[", 
            RowBox[{"[", "e", "]"}], "]"}], 
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "b", "]"}], "]"}], "[", 
            RowBox[{"[", "f", "]"}], "]"}], 
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "c", "]"}], "]"}], "[", 
            RowBox[{"[", "p", "]"}], "]"}], 
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "d", "]"}], "]"}], "[", 
            RowBox[{"[", "q", "]"}], "]"}], 
           RowBox[{"Rdddd", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], 
           RowBox[{"starRdddd", "[", 
            RowBox[{"e", ",", "f", ",", "p", ",", "q"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"d", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"e", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"f", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"b", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"p", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"q", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.53716883389548*^9, 3.537168841664504*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.16999899999999`", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "AA", " ", "\[Epsilon]p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"F", "[", "r", "]"}]}], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"h0", "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["h1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}], "-", 
           RowBox[{
            SuperscriptBox["h0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["S\[Theta]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "-", 
        RowBox[{
         SuperscriptBox["S\[CurlyPhi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["r", "5"], " ", 
      SqrtBox[
       RowBox[{"X", "[", "\[Theta]", "]"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.539870258061261*^9, 3.539871960652998*^9, 
  3.539873895645301*^9, 3.5701897548452473`*^9, 3.5702018570863037`*^9, 
  3.570203926059886*^9, 3.570287714219344*^9, 3.570287898594297*^9, 
  3.570288534710453*^9, 3.5702893043605547`*^9, 3.570289608408189*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definitions", "Section"]], "Subtitle",
 CellChangeTimes->{{3.4748662984784307`*^9, 3.474866318276967*^9}, {
  3.49682537622365*^9, 3.496825382669928*^9}, {3.516876275160224*^9, 
  3.516876279587028*^9}, {3.5355440086694717`*^9, 3.535544016131024*^9}, {
  3.5715199784015303`*^9, 3.571519985046792*^9}, {3.571520058485901*^9, 
  3.571520060481378*^9}}],

Cell[CellGroupData[{

Cell["\<\
Definitions [the reduce to Yunes and Pretorius, but can be more general]\
\>", "Subsubsection",
 CellChangeTimes->{{3.5370795551569223`*^9, 3.537079557613431*^9}, {
  3.53716604487469*^9, 3.5371660983771477`*^9}, {3.570189777626329*^9, 
  3.570189777766243*^9}, {3.570189816108219*^9, 3.570189817962185*^9}, {
  3.5715199692130404`*^9, 3.5715199712918367`*^9}, {3.57152020460357*^9, 
  3.5715202132945423`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "F", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f0", "[", "x_", "]"}], ":=", 
    FractionBox["1", 
     RowBox[{"2", " ", "\[Kappa]"}]]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"\[Kappa]", "=", 
    RowBox[{"8", "\[Pi]G"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f4", "[", "x_", "]"}], ":=", 
   RowBox[{
    FractionBox["\[Alpha]", "4"], " ", "x"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "x_", "]"}], ":=", 
   FractionBox["\[Beta]", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"V", "[", "x_", "]"}], ":=", 
    FractionBox[
     RowBox[{"2", "\[CapitalLambda]"}], 
     RowBox[{"2", "\[Kappa]"}]]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Clear", "[", "V", "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.537081457263674*^9, 3.537081517715323*^9}, {
  3.537081557634454*^9, 3.537081586309519*^9}, {3.539870289316473*^9, 
  3.539870291608993*^9}, {3.57018975591131*^9, 3.57018976280822*^9}, {
  3.570189810738473*^9, 3.570189810943007*^9}, {3.570190126182741*^9, 
  3.570190138702359*^9}, {3.570201862915752*^9, 3.570201863867847*^9}, {
  3.570203850511506*^9, 3.570203853064136*^9}, {3.570287740356662*^9, 
  3.5702877416828327`*^9}, {3.570288181855608*^9, 3.57028818275926*^9}, {
  3.570288934051878*^9, 3.570288944144288*^9}, {3.57028897954547*^9, 
  3.570288981851881*^9}, {3.570289308697011*^9, 3.5702893144790297`*^9}, {
  3.570289361597618*^9, 3.570289364746562*^9}, {3.570289568794187*^9, 
  3.570289569644855*^9}, {3.5702896106938953`*^9, 3.570289615876789*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Phi]", ",", "\[CapitalPhi]1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     RowBox[{"\[Epsilon]a", "*", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "*", 
      RowBox[{"\[CapitalPhi]1", "[", "r", "]"}]}], "+", 
     RowBox[{"\[Epsilon]p", " ", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
      RowBox[{"\[Phi]p", "[", 
       RowBox[{"r", ",", "t"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Gamma]", "[", "\[Phi]", "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], "]"}], 
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "-", 
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"i", ",", "j"}], "]"}], 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"guu", "[", 
                   RowBox[{"[", "a", "]"}], "]"}], "[", 
                  RowBox[{"[", "b", "]"}], "]"}], 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Phi]", ",", 
                   RowBox[{"x", "[", 
                    RowBox[{"[", "a", "]"}], "]"}]}], "]"}], 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Phi]", ",", 
                   RowBox[{"x", "[", 
                    RowBox[{"[", "b", "]"}], "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"b", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], 
            ")"}]}], "-", 
          RowBox[{
           RowBox[{"g", "[", 
            RowBox[{"i", ",", "j"}], "]"}], " ", 
           RowBox[{"V", "[", "\[Phi]", "]"}]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{"D", "[", 
                  RowBox[{
                   RowBox[{"f0", "[", "\[Phi]", "]"}], ",", 
                   RowBox[{"x", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                 RowBox[{"x", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "-", 
               RowBox[{"Sum", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Christ", "[", 
                   RowBox[{"i", ",", "j", ",", "l"}], "]"}], 
                  RowBox[{"D", "[", 
                   RowBox[{
                    RowBox[{"f0", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
              ")"}], "-", 
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"i", ",", "j"}], "]"}], 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"guu", "[", 
                   RowBox[{"[", "a", "]"}], "]"}], "[", 
                  RowBox[{"[", "b", "]"}], "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f0", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "a", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "b", "]"}], "]"}]}], "]"}], "-", 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Christ", "[", 
                    RowBox[{"a", ",", "b", ",", "l"}], "]"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f0", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
                  ")"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"b", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], 
            ")"}]}]}], ")"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5070553674922*^9, 3.5070554331057997`*^9}, {
   3.5072301775098*^9, 3.5072301899448*^9}, 3.516876284609981*^9, {
   3.5168763325941973`*^9, 3.516876352202737*^9}, {3.522752029870883*^9, 
   3.522752039572269*^9}, {3.52275218691698*^9, 3.522752211182843*^9}, {
   3.522752272386806*^9, 3.522752341418209*^9}, 3.535544390787858*^9, {
   3.535544857122135*^9, 3.535544859394916*^9}, {3.535545017626175*^9, 
   3.535545059285639*^9}, 3.535545429286491*^9, {3.537079149845564*^9, 
   3.537079150638261*^9}, {3.537079195399673*^9, 3.537079235667745*^9}, {
   3.5370792844872417`*^9, 3.537079313596644*^9}, {3.537079371328751*^9, 
   3.537079422483756*^9}, {3.537079472944002*^9, 3.5370794794811907`*^9}, {
   3.5370795266231747`*^9, 3.537079526646927*^9}, {3.53708177871449*^9, 
   3.537081787703926*^9}, 3.537081899531383*^9, {3.53708918761799*^9, 
   3.537089189543503*^9}, {3.537091372049623*^9, 3.537091376054389*^9}, {
   3.5370938083613033`*^9, 3.537093808379181*^9}, 3.537095346147407*^9, 
   3.5370987033342657`*^9, {3.537162897727051*^9, 3.5371629134523277`*^9}, {
   3.5371718765199413`*^9, 3.537171891480652*^9}, 3.5398702834936953`*^9, 
   3.570203820180587*^9, {3.5702885478054657`*^9, 3.570288548667232*^9}, {
   3.570289622221549*^9, 3.570289623642666*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Other definitions [see Yunes & Stein] [this takes some time]\
\>", "Subsubsection",
 CellChangeTimes->{{3.522752051838017*^9, 3.5227520543323708`*^9}, {
  3.571520008159513*^9, 3.571520064461937*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalKappa]", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"BISERIES", "[", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Sum", "[", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{
                   RowBox[{"gdd", "[", 
                    RowBox[{"[", "a", "]"}], "]"}], "[", 
                   RowBox[{"[", "q", "]"}], "]"}], " ", 
                  RowBox[{"D", "[", 
                   RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "c", "]"}], "]"}]}], "]"}], 
                  RowBox[{"ETA", "[", 
                   RowBox[{"c", ",", "d", ",", "e", ",", "q"}], "]"}], " ", 
                  RowBox[{"NABLAR", "[", 
                   RowBox[{"e", ",", "b", ",", "d"}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"d", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"e", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"q", ",", "1", ",", "dim"}], "}"}]}], "]"}], "+", 
               " ", 
               RowBox[{"4", " ", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "d", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "c", "]"}], "]"}]}], "]"}], "-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Christ", "[", 
                    RowBox[{"c", ",", "d", ",", "l"}], "]"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
                    ")"}], 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"starRdddd", "[", 
                    RowBox[{"a", ",", "l", ",", "b", ",", "m"}], "]"}], 
                    RowBox[{
                    RowBox[{"guu", "[", 
                    RowBox[{"[", "l", "]"}], "]"}], "[", 
                    RowBox[{"[", "c", "]"}], "]"}], 
                    RowBox[{
                    RowBox[{"guu", "[", 
                    RowBox[{"[", "m", "]"}], "]"}], "[", 
                    RowBox[{"[", "d", "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"l", ",", "1", ",", "dim"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"m", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
                  ",", 
                  RowBox[{"{", 
                   RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"d", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], 
              ")"}], "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Sum", "[", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{
                   RowBox[{"gdd", "[", 
                    RowBox[{"[", "b", "]"}], "]"}], "[", 
                   RowBox[{"[", "q", "]"}], "]"}], " ", 
                  RowBox[{"D", "[", 
                   RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "c", "]"}], "]"}]}], "]"}], 
                  RowBox[{"ETA", "[", 
                   RowBox[{"c", ",", "d", ",", "e", ",", "q"}], "]"}], " ", 
                  RowBox[{"NABLAR", "[", 
                   RowBox[{"e", ",", "a", ",", "d"}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"d", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"e", ",", "1", ",", "dim"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"q", ",", "1", ",", "dim"}], "}"}]}], "]"}], "+", 
               " ", 
               RowBox[{"4", " ", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "d", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "c", "]"}], "]"}]}], "]"}], "-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Christ", "[", 
                    RowBox[{"c", ",", "d", ",", "l"}], "]"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"f4", "[", "\[Phi]", "]"}], ",", 
                    RowBox[{"x", "[", 
                    RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
                    ")"}], 
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"starRdddd", "[", 
                    RowBox[{"b", ",", "l", ",", "a", ",", "m"}], "]"}], 
                    RowBox[{
                    RowBox[{"guu", "[", 
                    RowBox[{"[", "l", "]"}], "]"}], "[", 
                    RowBox[{"[", "c", "]"}], "]"}], 
                    RowBox[{
                    RowBox[{"guu", "[", 
                    RowBox[{"[", "m", "]"}], "]"}], "[", 
                    RowBox[{"[", "d", "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"l", ",", "1", ",", "dim"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"m", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
                  ",", 
                  RowBox[{"{", 
                   RowBox[{"c", ",", "1", ",", "dim"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"d", ",", "1", ",", "dim"}], "}"}]}], "]"}]}]}], 
              ")"}]}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
        "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.504339204708129*^9, 3.504339219231186*^9}, {
   3.504367618486244*^9, 3.504367691394435*^9}, 3.504368472214899*^9, {
   3.5043697661484756`*^9, 3.504369767485611*^9}, {3.504369798406535*^9, 
   3.504369847927136*^9}, {3.5043699791112328`*^9, 3.504370127579967*^9}, {
   3.5043701791218357`*^9, 3.504370181810267*^9}, {3.50437025557936*^9, 
   3.504370375052896*^9}, {3.504371033106167*^9, 3.5043710991518507`*^9}, {
   3.5043711410046997`*^9, 3.504371257801826*^9}, {3.504371363058503*^9, 
   3.504371363496126*^9}, {3.504371451316025*^9, 3.504371451858015*^9}, {
   3.504378893683617*^9, 3.504378899049893*^9}, {3.504379122174995*^9, 
   3.5043791256686707`*^9}, {3.504857315329111*^9, 3.504857319997603*^9}, {
   3.504862261321198*^9, 3.504862267442967*^9}, {3.504867186263814*^9, 
   3.504867189395484*^9}, {3.50487485663568*^9, 3.504874856871339*^9}, {
   3.504875389135828*^9, 3.504875392017563*^9}, {3.50487560868108*^9, 
   3.5048756235124702`*^9}, {3.5048757118960657`*^9, 3.504875758158873*^9}, {
   3.5048763360614758`*^9, 3.504876337358117*^9}, {3.504877006871121*^9, 
   3.504877028950017*^9}, {3.504877237788301*^9, 3.504877242069632*^9}, {
   3.504877308185709*^9, 3.504877333331081*^9}, 3.504877531607045*^9, {
   3.504877638627747*^9, 3.504877638865617*^9}, {3.504877767813726*^9, 
   3.504877770667585*^9}, {3.504878093951314*^9, 3.504878098351089*^9}, {
   3.504878778334559*^9, 3.50487884742492*^9}, {3.504878907147071*^9, 
   3.5048789514817543`*^9}, 3.504878994634577*^9, {3.504879121809643*^9, 
   3.5048791223724537`*^9}, {3.504879156597131*^9, 3.504879160546423*^9}, {
   3.504879346376237*^9, 3.5048793762911463`*^9}, {3.5070146953287005`*^9, 
   3.5070147453891006`*^9}, 3.507015658481701*^9, {3.5070157111317005`*^9, 
   3.5070157626117005`*^9}, {3.5227523284474792`*^9, 
   3.5227523284743156`*^9}, {3.53554502040479*^9, 3.535545020430303*^9}, {
   3.5370793875619717`*^9, 3.537079387581514*^9}, 3.537091299236113*^9, {
   3.537091438507456*^9, 3.5370914389086313`*^9}, {3.537091593288226*^9, 
   3.537091600128582*^9}, {3.537091633145805*^9, 3.537091679339878*^9}, {
   3.537091830221064*^9, 3.5370918831251917`*^9}, 3.537093808409081*^9, 
   3.537095346333444*^9, 3.537098703987789*^9, {3.53716301995364*^9, 
   3.537163022711349*^9}, {3.537171502664823*^9, 3.5371715103266497`*^9}, {
   3.571520044492408*^9, 3.571520045125897*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"120.94665500000002`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.539870303267908*^9, 3.539871549731167*^9, 
  3.539871976531749*^9, 3.539873909203371*^9, 3.570190140369392*^9, 
  3.5701914829172583`*^9, 3.570202935903986*^9, 3.570205085430414*^9, 
  3.570287854680908*^9, 3.57028804118605*^9, 3.570288686510826*^9, 
  3.570289326734552*^9, 3.570289800917656*^9, 3.570290082393849*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.504877641361475*^9, 3.504877674963995*^9}, {
   3.5048777117691*^9, 3.5048777193440742`*^9}, {3.504877808186829*^9, 
   3.5048778902314262`*^9}, {3.504878116435614*^9, 3.504878132089444*^9}, {
   3.504878223368712*^9, 3.504878270548524*^9}, {3.504878403212489*^9, 
   3.504878403419552*^9}, {3.504879004949594*^9, 3.504879076851186*^9}, 
   3.504879129995695*^9, {3.516877916016933*^9, 3.51687793306859*^9}, 
   3.522752328486005*^9, 3.5355450204486303`*^9, 3.537079387598462*^9, {
   3.537083350269745*^9, 3.537083352093474*^9}, 3.5715200430938807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Modified Einstein equations:", "Section"]], \
"Subsubtitle",
 CellChangeTimes->{{3.4752347350130568`*^9, 3.475234738813002*^9}, {
   3.4752348715391417`*^9, 3.4752348766308603`*^9}, {3.504423513761092*^9, 
   3.504423516836102*^9}, 3.571520066211913*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"EQEINST", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{
         RowBox[{"Ricci", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "-", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"g", "[", 
           RowBox[{"i", ",", "j"}], "]"}], " ", "SCAL"}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"f0", "[", "\[Phi]", "]"}], ")"}], 
           RowBox[{"-", "1"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalKappa]", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "-", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"T", "[", 
              RowBox[{"i", ",", "j"}], "]"}]}]}], ")"}]}]}], "]"}], "]"}]}], 
     ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.494340702923778*^9, 3.494340706649364*^9}, {
   3.4945847708411217`*^9, 3.494584822763629*^9}, {3.494586643087392*^9, 
   3.494586644685483*^9}, {3.4946745839591017`*^9, 3.494674598184272*^9}, {
   3.4948633756636333`*^9, 3.494863377186764*^9}, {3.494863420298729*^9, 
   3.494863426175583*^9}, {3.496820404968685*^9, 3.496820452438518*^9}, {
   3.496821540379427*^9, 3.496821554543049*^9}, {3.504332748727181*^9, 
   3.5043327541579638`*^9}, {3.5043328697883263`*^9, 3.504332870084283*^9}, {
   3.5043391281428413`*^9, 3.504339187096039*^9}, {3.504428270801147*^9, 
   3.504428271363044*^9}, {3.5044286466453247`*^9, 3.5044286468187838`*^9}, {
   3.5044492158292294`*^9, 3.5044492351069727`*^9}, {3.50470795041389*^9, 
   3.504707981830139*^9}, 3.5047095121518087`*^9, 3.504710015264078*^9, {
   3.522752329827031*^9, 3.5227523298463087`*^9}, {3.535545022524313*^9, 
   3.535545022549247*^9}, {3.5370793893347683`*^9, 3.537079389340351*^9}, {
   3.53708320277229*^9, 3.537083256254108*^9}, {3.5371629800080442`*^9, 
   3.5371629828443127`*^9}, {3.5371630418447313`*^9, 3.537163044309452*^9}, {
   3.570189843421536*^9, 3.570189844065825*^9}, {3.571520068136362*^9, 
   3.571520077411323*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Scalar equation:", "Section"]], "Subsubtitle",
 CellChangeTimes->{{3.4752347350130568`*^9, 3.475234738813002*^9}, {
  3.4752348715391417`*^9, 3.4752348766308603`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LHS", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SqrtBox[
           RowBox[{"-", "DET"}]]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              SqrtBox[
               RowBox[{"-", "DET"}]], 
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"x", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RHS", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", "\[Phi]", "]"}]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"V", "'"}], "[", "\[Phi]", "]"}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"f4", "'"}], "[", "\[Phi]", "]"}], "starRR"}]}], ")"}]}],
         ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQDIL", "=", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"(", 
     RowBox[{"LHS", "-", "RHS"}], ")"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.494225822714517*^9, 3.494225935651701*^9}, {
   3.494243736231841*^9, 3.4942437433275423`*^9}, {3.494344012142809*^9, 
   3.494344022967853*^9}, 3.494587505070442*^9, {3.494863435052575*^9, 
   3.4948634359432697`*^9}, {3.49682046055167*^9, 3.4968204993881083`*^9}, {
   3.496821062920734*^9, 3.49682106467972*^9}, {3.496826487559401*^9, 
   3.496826497085766*^9}, {3.496826806176692*^9, 3.49682685664093*^9}, 
   3.4969002716964293`*^9, {3.496900510680613*^9, 3.496900523596499*^9}, {
   3.499429487924271*^9, 3.499429527785096*^9}, {3.499430111837267*^9, 
   3.499430122180519*^9}, {3.499430274903297*^9, 3.499430282846136*^9}, {
   3.504422247464003*^9, 3.504422247572927*^9}, {3.5044223102555227`*^9, 
   3.5044223136485167`*^9}, {3.504422614798112*^9, 3.504422640337072*^9}, {
   3.504423326060687*^9, 3.504423388816689*^9}, {3.504423450598926*^9, 
   3.504423468146142*^9}, 3.504423525421028*^9, {3.504423611335539*^9, 
   3.504423616616745*^9}, {3.50442822414247*^9, 3.504428256492443*^9}, {
   3.504428658875153*^9, 3.504428659513832*^9}, {3.5070160480917006`*^9, 
   3.507016080711301*^9}, {3.507016234230901*^9, 3.5070162366489005`*^9}, {
   3.5168771128603287`*^9, 3.516877179312602*^9}, {3.516877213347224*^9, 
   3.5168772626777897`*^9}, {3.516877308354082*^9, 3.516877391526739*^9}, {
   3.522752329886785*^9, 3.522752341500141*^9}, {3.535545022567733*^9, 
   3.535545022914996*^9}, {3.535545059441247*^9, 3.535545059450307*^9}, {
   3.537079389352181*^9, 3.537079389479549*^9}, {3.5370794235038633`*^9, 
   3.537079438156742*^9}, {3.537079525138042*^9, 3.537079525212371*^9}, {
   3.537081815890856*^9, 3.537081816853009*^9}, {3.537084208404068*^9, 
   3.537084208824049*^9}, {3.5370938085780478`*^9, 3.5370938086021833`*^9}, {
   3.53709534687464*^9, 3.537095347212886*^9}, {3.537098704623885*^9, 
   3.5370987049623833`*^9}, {3.5371630742073193`*^9, 3.537163089418721*^9}, {
   3.570289340456675*^9, 3.570289344509976*^9}, {3.570289661892674*^9, 
   3.5702896887024317`*^9}}],

Cell[CellGroupData[{

Cell["EXPORTING", "Subsection",
 CellChangeTimes->{{3.537168911047113*^9, 3.5371689148133717`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq11", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq12", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq13", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq14", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq22", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq23", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq24", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq33", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"3", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq34", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"3", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq44", "=", 
    RowBox[{"EQEINST", "[", 
     RowBox[{"4", ",", "4"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<DCS_eqs_first_order_potential.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "EQDIL", ",", "eq11", ",", "eq12", ",", "eq13", ",", "eq14", ",", "eq22",
       ",", "eq23", ",", "eq24", ",", "eq33", ",", "eq34", ",", "eq44"}], 
     "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537168916944661*^9, 3.537169101845484*^9}, {
  3.539870324203175*^9, 3.539870334908463*^9}, {3.57018991498676*^9, 
  3.570189915619968*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbation equations:", "Section",
 CellChangeTimes->{{3.499430303861505*^9, 3.499430307057025*^9}, {
   3.4994844280649767`*^9, 3.499484429446755*^9}, 3.53708175589865*^9, {
   3.537093339766152*^9, 3.537093355082137*^9}, {3.570288219472118*^9, 
   3.570288222881703*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<DCS_eqs_first_order_potential.mx\>\""}], ";"}]}], "Input",\

 CellChangeTimes->{{3.570293221132848*^9, 3.5702932223141117`*^9}}],

Cell[CellGroupData[{

Cell["Check background:", "Subsubsection",
 CellChangeTimes->{{3.5702882266473017`*^9, 3.570288231650362*^9}, 
   3.570290157130637*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{"2", "M"}], "r"], "-", 
    RowBox[{
     FractionBox["\[CapitalLambda]", "3"], 
     SuperscriptBox["r", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "eq11", ",", "eq12", ",", "eq13", ",", "eq14", ",", "eq22", ",", "eq23", 
     ",", "eq24", ",", "eq33", ",", "eq34", ",", "eq44", ",", "EQDIL"}], 
    "}"}], "/.", 
   RowBox[{"\[Epsilon]p", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5702881032006407`*^9, 3.570288156225842*^9}, {
   3.570288287871933*^9, 3.570288289664433*^9}, {3.570288901329872*^9, 
   3.570288901777499*^9}, {3.570289351294875*^9, 3.570289351430051*^9}, {
   3.570289563177297*^9, 3.570289563425212*^9}, 3.570290157132498*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.570288104087433*^9, 3.570288110969286*^9}, 
   3.570288156890921*^9, 3.5702886881468067`*^9, {3.5702888885771437`*^9, 
   3.570288903704213*^9}, 3.5702893519539433`*^9, 3.570289563777995*^9, 
   3.5702898854537077`*^9, 3.570290084162673*^9, {3.570290152282196*^9, 
   3.570290157135005*^9}, 3.570293223815036*^9, 3.5702963555203533`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angular part", "Subsubsection",
 CellChangeTimes->{{3.537169436071678*^9, 3.537169438199121*^9}, {
  3.570290299509068*^9, 3.5702903119648457`*^9}, {3.5702904299817038`*^9, 
  3.570290434924295*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "\[Theta]_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S\[Theta]", "[", 
    RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "1"}], 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[CurlyPhi]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"S\[CurlyPhi]", "[", 
     RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[Theta]"}], 
      "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleANG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], 
        RowBox[{"(", 
         RowBox[{"l", "+", "1"}], ")"}], 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"4", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", "l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{"Csc", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{
               SuperscriptBox["Y", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.537248251134644*^9, 3.537248268481345*^9}, {
  3.5372500792999687`*^9, 3.537250088360345*^9}, {3.537253909457386*^9, 
  3.537253926144947*^9}, {3.5372539814636497`*^9, 3.5372539881597357`*^9}, {
  3.570290212133354*^9, 3.5702902132549753`*^9}, {3.5702903242941227`*^9, 
  3.570290332470255*^9}, {3.570290415263435*^9, 3.570290427292472*^9}, {
  3.570290559879512*^9, 3.570290571550837*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["First order:", "Subsubsection",
 CellChangeTimes->{{3.5702882360083113`*^9, 3.57028823745024*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h0", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}], 
    RowBox[{"h0", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}], 
    FractionBox[
     RowBox[{
      RowBox[{"-", "I"}], " ", "AA", " ", "\[Omega]", " ", "r", " ", 
      RowBox[{"Q", "[", "r", "]"}]}], 
     RowBox[{"F", "[", "r", "]"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]p", "[", 
     RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}], 
     FractionBox[
      RowBox[{"\[CapitalTheta]", "[", "r", "]"}], "r"]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E11", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq11", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E12", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq12", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E13", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq13", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E14", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq14", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E22", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq22", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E23", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq23", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E24", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq24", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E33", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq33", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E34", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq34", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E44", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq44", "//.", "ruleANG"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ES", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"EQDIL", "//.", "ruleANG"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.570290162867858*^9, 3.5702901664326487`*^9}, {
   3.5702902191939993`*^9, 3.570290256305251*^9}, {3.570290438980462*^9, 
   3.5702904542845488`*^9}, {3.570290489134317*^9, 3.5702905810737743`*^9}, {
   3.570290615631095*^9, 3.570290654651339*^9}, 3.570290887983172*^9, {
   3.570296467520794*^9, 3.5702964705069313`*^9}, {3.570296501369755*^9, 
   3.570296519022352*^9}, {3.570296574251389*^9, 3.570296576922585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"h0n", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"E44", "\[Equal]", "0"}], ",", 
     RowBox[{"h0", "[", "r", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleh0", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"h0n", ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0n", ",", "r"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0n", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.570290660080536*^9, 3.570290689917547*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"h0", "[", "r", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"AA", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "M"}], "-", 
        RowBox[{"3", " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", "r", "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["Q", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
     RowBox[{"3", " ", "r"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.570290667067821*^9, 3.5702906917681513`*^9}, 
   3.570290892186311*^9, 3.570293232009009*^9, 3.570296368352169*^9, 
   3.57029647544738*^9, 3.570296523868041*^9, 3.570296582682777*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"syst", "=", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"E23", "//.", "ruleh0"}], ")"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ES", "//.", "ruleh0"}], ")"}], "\[Equal]", "0"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "''"}], "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}],
     "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.57029073166098*^9, 3.5702907731823378`*^9}, {
   3.570290816912318*^9, 3.5702908174393997`*^9}, 3.570290893772119*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["Q", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["r", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "M"}], "-", 
          RowBox[{"3", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], 
        "2"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", "M"}], "-", 
              RowBox[{"l", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], ")"}]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "M"}], "-", 
             RowBox[{"3", " ", "r"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}]}], 
          "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["r", "4"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
        RowBox[{"Q", "[", "r", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "M"}], "-", 
          RowBox[{"3", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
        
        RowBox[{"(", 
         RowBox[{
          RowBox[{"18", " ", "M", " ", "\[Alpha]", " ", "\[Kappa]", " ", 
           RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "M"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["Q", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalTheta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["r", "7"], " ", "\[Beta]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "M"}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], 
         "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"18", " ", 
         SuperscriptBox["AA", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "l"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "l"}], ")"}], " ", "M", " ", 
         SuperscriptBox["r", "3"], " ", "\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "M"}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
         RowBox[{"Q", "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", "M"}], "-", 
              RowBox[{"3", " ", "r"}], "+", 
              RowBox[{
               SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["r", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "M"}], "+", 
                 RowBox[{"l", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], ")"}], " ", 
               "\[Beta]"}], "+", 
              RowBox[{"216", " ", 
               SuperscriptBox["AA", "2"], " ", "l", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "l"}], ")"}], " ", 
               SuperscriptBox["M", "2"], " ", 
               SuperscriptBox["\[Alpha]", "2"], " ", "\[Kappa]"}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "8"], " ", "\[Beta]", " ", 
               "\[CapitalLambda]"}]}], ")"}]}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["r", "9"], " ", "\[Beta]", " ", 
            SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
         RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "6"], " ", "\[Beta]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", "M"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "M"}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[CapitalTheta]", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5702907600712767`*^9, 3.570290775139422*^9}, 
   3.570290817722324*^9, 3.570290895133718*^9, 3.570293233809935*^9, 
   3.570296370117342*^9, 3.570296477237743*^9, 3.5702965247284517`*^9, 
   3.570296584179514*^9}]
}, Open  ]],

Cell["All equations are satisfied:", "Text",
 CellChangeTimes->{{3.57029082487051*^9, 3.570290837067377*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "eq11", ",", "eq12", ",", "eq13", ",", "eq14", ",", "eq22", ",", "eq23", 
     ",", "eq24", ",", "eq33", ",", "eq34", ",", "eq44", ",", "EQDIL"}], 
    "}"}], "//.", 
   RowBox[{"Union", "[", 
    RowBox[{"ruleh0", ",", "ruleANG", ",", "syst", ",", 
     RowBox[{"D", "[", 
      RowBox[{"syst", ",", "r"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.570290693271555*^9, 3.57029072101027*^9}, {
  3.5702907958033953`*^9, 3.570290814872334*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.570290699991022*^9, 3.570290721579701*^9}, 
   3.570290819845229*^9, 3.570290897903981*^9, 3.570293235301399*^9, 
   3.5702963714851627`*^9, 3.570296479219667*^9, 3.570296526948533*^9, 
   3.5702965871607122`*^9}]
}, Open  ]],

Cell["Let us rewrite the system in a Schroedinger-like form:", "Text",
 CellChangeTimes->{{3.5702908463857107`*^9, 3.5702908573625917`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"e1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "''"}], "[", "r", "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "''"}], "[", "r", "]"}], "/.", "syst"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}], "/.", "syst"}], 
     ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.570290861633758*^9, 3.570290884050066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"c1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"Coefficient", "[", 
      RowBox[{"e1", ",", 
       RowBox[{
        RowBox[{"Q", "'"}], "[", "r", "]"}]}], "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"e1", ",", 
       RowBox[{
        RowBox[{"Q", "''"}], "[", "r", "]"}]}], "]"}]], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"F", "[", "r", "]"}], "2"], 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}]}]]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"c2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"Coefficient", "[", 
      RowBox[{"e2", ",", 
       RowBox[{
        RowBox[{"\[CapitalTheta]", "'"}], "[", "r", "]"}]}], "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"e2", ",", 
       RowBox[{
        RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "]"}]], 
    FractionBox[
     SuperscriptBox[
      RowBox[{"F", "[", "r", "]"}], "2"], 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}]}]]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"V1", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], "-", 
     RowBox[{
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"e1", ",", 
         RowBox[{"Q", "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"e1", ",", 
         RowBox[{
          RowBox[{"Q", "''"}], "[", "r", "]"}]}], "]"}]], 
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"]}]}], 
    RowBox[{"F", "[", "r", "]"}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"V2", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], "-", 
     RowBox[{
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"e2", ",", 
         RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"e2", ",", 
         RowBox[{
          RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "]"}]], 
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"]}]}], 
    RowBox[{"F", "[", "r", "]"}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"S1", "=", 
  RowBox[{"-", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"e1", ",", 
         RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"e1", ",", 
         RowBox[{
          RowBox[{"Q", "''"}], "[", "r", "]"}]}], "]"}]], 
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"]}], 
     RowBox[{"F", "[", "r", "]"}]], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"S2", "=", 
  RowBox[{"-", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"e2", ",", 
         RowBox[{"Q", "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"e2", ",", 
         RowBox[{
          RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "]"}]], 
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"]}], 
     RowBox[{"F", "[", "r", "]"}]], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.570290905695291*^9, 3.5702909987428303`*^9}, {
  3.570291028817616*^9, 3.570291067052243*^9}, {3.570291135095482*^9, 
  3.570291137447159*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.57029658819921*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.570296588202615*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "M"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], 
  SuperscriptBox["r", "3"]]], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.57029658820548*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["r", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "+", 
      RowBox[{"l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], ")"}], " ", "\[Beta]"}],
    "+", 
   RowBox[{"216", " ", 
    SuperscriptBox["AA", "2"], " ", "l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", "\[Kappa]"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "8"], " ", "\[Beta]", " ", "\[CapitalLambda]"}]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["r", "8"], " ", "\[Beta]"}]]], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.5702965882079897`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"12", " ", "M", " ", "\[Alpha]", " ", "\[Kappa]"}], 
  SuperscriptBox["r", "5"]]], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.5702965882108192`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"6", " ", 
   SuperscriptBox["AA", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "l"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "l"}], ")"}], " ", "M", " ", "\[Alpha]"}], 
  RowBox[{
   SuperscriptBox["r", "5"], " ", "\[Beta]"}]]], "Output",
 CellChangeTimes->{{3.570290944887219*^9, 3.57029107088424*^9}, 
   3.57029116443823*^9, 3.570293235936857*^9, 3.570296371590969*^9, 
   3.570296480860289*^9, 3.5702965273159533`*^9, 3.570296588214303*^9}]
}, Open  ]],

Cell["CHECK:", "Text",
 CellChangeTimes->{{3.57029107855717*^9, 3.57029108002176*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"e1", " ", 
     SuperscriptBox[
      RowBox[{"F", "[", "r", "]"}], "2"]}], 
    RowBox[{"Coefficient", "[", 
     RowBox[{"e1", ",", 
      RowBox[{
       RowBox[{"Q", "''"}], "[", "r", "]"}]}], "]"}]], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{"Q", "''"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{
       RowBox[{"Q", "'"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], "V1"}]}], ")"}], 
      RowBox[{"Q", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], "S1", " ", 
      RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}]}], ")"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"e2", " ", 
     SuperscriptBox[
      RowBox[{"F", "[", "r", "]"}], "2"]}], 
    RowBox[{"Coefficient", "[", 
     RowBox[{"e2", ",", 
      RowBox[{
       RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "]"}]], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{
       RowBox[{"\[CapitalTheta]", "'"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], "V2"}]}], ")"}], 
      RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], "S2", " ", 
      RowBox[{"Q", "[", "r", "]"}]}]}], ")"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5702910812463293`*^9, 3.5702911881435757`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.5702911417312927`*^9, 3.570291188596505*^9}, 
   3.570293238989296*^9, 3.570296606864333*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.5702911417312927`*^9, 3.570291188596505*^9}, 
   3.570293238989296*^9, 3.5702966068661203`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"V1", ",", "V2", ",", "S1", ",", "S2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Infinity]", ",", "10"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.570291241274068*^9, 3.570291260505575*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"l", "+", 
       SuperscriptBox["l", "2"]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", "M"}], 
      SuperscriptBox["r", "3"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "11"],
      SeriesData[$CellContext`r, 
       DirectedInfinity[1], {}, 2, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 
     DirectedInfinity[
     1], {$CellContext`l + $CellContext`l^2, (-6) $CellContext`M}, 2, 11, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "\[CapitalLambda]"}], "3"]}], "+", 
     FractionBox[
      RowBox[{"l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", "M"}], 
      SuperscriptBox["r", "3"]], "+", 
     FractionBox[
      RowBox[{"72", " ", 
       SuperscriptBox["AA", "2"], " ", "l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}], " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", "\[Kappa]"}], 
      RowBox[{"\[Beta]", " ", 
       SuperscriptBox["r", "8"]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "11"],
      SeriesData[$CellContext`r, 
       DirectedInfinity[1], {}, 0, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 
     DirectedInfinity[1], {
     Rational[-2, 3] $CellContext`\[CapitalLambda], 
      0, $CellContext`l (1 + $CellContext`l), 2 $CellContext`M, 0, 0, 0, 0, 
      72 $CellContext`AA^2 $CellContext`l (
       1 + $CellContext`l) $CellContext`M^2 $CellContext`\[Alpha]^2 \
$CellContext`\[Beta]^(-1) $CellContext`\[Kappa]}, 0, 11, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", "M", " ", "\[Alpha]", " ", "\[Kappa]"}], 
      SuperscriptBox["r", "5"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "11"],
      SeriesData[$CellContext`r, 
       DirectedInfinity[1], {}, 5, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 
     DirectedInfinity[1], {
     12 $CellContext`M $CellContext`\[Alpha] $CellContext`\[Kappa]}, 5, 11, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox["AA", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "l"}], ")"}], " ", "M", " ", "\[Alpha]"}], 
      RowBox[{"\[Beta]", " ", 
       SuperscriptBox["r", "5"]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "11"],
      SeriesData[$CellContext`r, 
       DirectedInfinity[1], {}, 5, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 
     DirectedInfinity[1], {
     6 $CellContext`AA^2 (-1 + $CellContext`l) $CellContext`l (
       1 + $CellContext`l) (
       2 + $CellContext`l) $CellContext`M $CellContext`\[Alpha]/$CellContext`\
\[Beta]}, 5, 11, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.570291249039258*^9, 3.570291260835802*^9}, 
   3.570293241213985*^9, 3.570296608919697*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 625, 12, 66, "Subtitle"],
Cell[CellGroupData[{
Cell[1217, 38, 9340, 216, 290, "Input"],
Cell[10560, 256, 2839, 68, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13436, 329, 105, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[13566, 334, 3640, 95, 161, "Input"],
Cell[17209, 431, 3313, 80, 97, "Output"],
Cell[20525, 513, 4634, 120, 124, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25208, 639, 258, 5, 28, "Subsubsection"],
Cell[25469, 646, 2297, 58, 135, "Input"],
Cell[CellGroupData[{
Cell[27791, 708, 2568, 61, 138, "Input"],
Cell[30362, 771, 575, 9, 29, "Output"]
}, Open  ]],
Cell[30952, 783, 1051, 28, 29, "Input"],
Cell[32006, 813, 1495, 40, 48, "Input"],
Cell[33504, 855, 967, 26, 29, "Input"],
Cell[34474, 883, 1052, 29, 55, "Input"],
Cell[35529, 914, 1324, 35, 48, "Input"],
Cell[36856, 951, 1557, 41, 115, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38450, 997, 319, 6, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[38794, 1007, 1910, 47, 164, "Input"],
Cell[40707, 1056, 471, 8, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41215, 1069, 1833, 48, 120, "Input"],
Cell[43051, 1119, 398, 7, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43486, 1131, 2061, 52, 120, "Input"],
Cell[45550, 1185, 2432, 69, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48043, 1261, 375, 5, 46, "Subtitle"],
Cell[CellGroupData[{
Cell[48443, 1270, 421, 7, 28, "Subsubsection"],
Cell[48867, 1279, 1748, 43, 253, "Input"],
Cell[50618, 1324, 7203, 170, 210, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57858, 1499, 210, 4, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[58093, 1507, 10111, 213, 352, "Input"],
Cell[68207, 1722, 435, 7, 29, "Output"]
}, Open  ]],
Cell[68657, 1732, 603, 8, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69297, 1745, 278, 4, 34, "Subsubtitle"],
Cell[69578, 1751, 2338, 51, 56, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71953, 1807, 191, 2, 34, "Subsubtitle"],
Cell[72147, 1811, 4304, 94, 136, "Input"],
Cell[CellGroupData[{
Cell[76476, 1909, 99, 1, 37, "Subsection"],
Cell[76578, 1912, 1980, 57, 246, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78595, 1974, 281, 4, 71, "Section"],
Cell[78879, 1980, 301, 8, 48, "Input"],
Cell[CellGroupData[{
Cell[79205, 1992, 136, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[79366, 1998, 865, 21, 77, "Input"],
Cell[80234, 2021, 580, 11, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80863, 2038, 205, 3, 28, "Subsubsection"],
Cell[81071, 2043, 10902, 320, 314, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92010, 2368, 104, 1, 28, "Subsubsection"],
Cell[92117, 2371, 3053, 84, 342, "Input"],
Cell[CellGroupData[{
Cell[95195, 2459, 616, 18, 48, "Input"],
Cell[95814, 2479, 847, 23, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96698, 2507, 812, 24, 29, "Input"],
Cell[97513, 2533, 5840, 162, 132, "Output"]
}, Open  ]],
Cell[103368, 2698, 109, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[103502, 2703, 544, 13, 29, "Input"],
Cell[104049, 2718, 406, 8, 29, "Output"]
}, Open  ]],
Cell[104470, 2729, 140, 1, 28, "Text"],
Cell[104613, 2732, 616, 21, 48, "Input"],
Cell[CellGroupData[{
Cell[105254, 2757, 3529, 107, 382, "Input"],
Cell[108786, 2866, 233, 3, 29, "Output"],
Cell[109022, 2871, 234, 3, 29, "Output"],
Cell[109259, 2876, 429, 11, 50, "Output"],
Cell[109691, 2889, 916, 24, 56, "Output"],
Cell[110610, 2915, 338, 6, 50, "Output"],
Cell[110951, 2923, 592, 15, 56, "Output"]
}, Open  ]],
Cell[111558, 2941, 86, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[111669, 2946, 2134, 68, 115, "Input"],
Cell[113806, 3016, 144, 2, 29, "Output"],
Cell[113953, 3020, 146, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114136, 3027, 334, 9, 29, "Input"],
Cell[114473, 3038, 3604, 105, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
